@@ -82,8 +82,16 @@ public class LoginCredentials {
     @NonFinal
     String forwardedFor;
 
+    @Wither
+    @NonFinal
+    String forwardedProto;
+
     @Wither
     @NonFinal
     String userAgent;
 
+    @Wither
+    @NonFinal
+    String trackingId;
+
 }
\ No newline at end of file
