@@ -175,7 +175,9 @@ public class MailCto {
             return null;
         }
         for (AttachmentCto part : parts) {
-            if (!"attachment".equals(part.getDisposition())) {
+            //if (!"attachment".equals(part.getDisposition())) {
+            if (!("attachment".equals(part.getDisposition()) ||
+                    ("inline".equals(part.getDisposition()) && !("text/plain".equals(part.getContentType()) ||"text/html".equals(part.getContentType()))))) {
                 return part;
             }
         }
@@ -188,7 +190,9 @@ public class MailCto {
         }
         for (Iterator<AttachmentCto> it = attachments.iterator(); it.hasNext(); ) {
             AttachmentCto attachment = it.next();
-            if (!"attachment".equals(attachment.getDisposition())) {
+            //if (!"attachment".equals(attachment.getDisposition())) {
+            if (!("attachment".equals(attachment.getDisposition()) ||
+                    ("inline".equals(attachment.getDisposition()) && !("text/plain".equals(attachment.getContentType()) ||"text/html".equals(attachment.getContentType()))))) {
                 it.remove();
             }
         }
