@@ -151,7 +151,7 @@ public class Mail {
         this.parts = null;
     }
 
-    private Mail(String id, int flags, int color, Long receivedDate, List<MailContact> from, List<MailContact> to, List<MailContact> cc, List<MailContact> bcc, String subject, String teaser, Long sentDate) {
+    private Mail(String id, int flags, int color, Long receivedDate, List<MailContact> from, List<MailContact> to, List<MailContact> cc, List<MailContact> bcc, String subject, String teaser, Long sentDate, Integer priority) {
         this.id = id;
         this.flags = new MailFlags(flags);
         this.color = nonZero(color);
@@ -171,7 +171,7 @@ public class Mail {
         this.contentType = null;
         this.hasAttachments = null;
         this.size = null;
-        this.priority = null;
+        this.priority = Priority.valueOf(priority);
         this.parts = null;
     }
 
@@ -211,8 +211,8 @@ public class Mail {
         return new Mail(id, flags, color, receivedDate, level);
     }
 
-    public static Mail createEnvelope(String id, int flags, int color, Long receivedDate, List<MailContact> from, List<MailContact> to, List<MailContact> cc, List<MailContact> bcc, String subject, String teaser, Long sentDate) {
-        return new Mail(id, flags, color, receivedDate, from, to, cc, bcc, subject, teaser, sentDate);
+    public static Mail createEnvelope(String id, int flags, int color, Long receivedDate, List<MailContact> from, List<MailContact> to, List<MailContact> cc, List<MailContact> bcc, String subject, String teaser, Long sentDate, Integer priority) {
+        return new Mail(id, flags, color, receivedDate, from, to, cc, bcc, subject, teaser, sentDate, priority);
     }
 
     public static Mail createMail(MailMto mailMto) {
