@@ -114,6 +114,8 @@ public class RequestUtil {
 
     public static final String HEADER_X_FORWARDED_FOR = "X-Forwarded-For";
 
+    public static final String HEADER_X_FORWARDED_PROTO = "X-Forwarded-Proto";
+
     public static final String HEADER_HOST = "Host";
 
     public static final String HEADER_X_HOST = "X-Host";
@@ -182,6 +184,7 @@ public class RequestUtil {
         return sessionData
                 .withHost(hostname)
                 .withForwardedFor(getForwardedForWithRemoteIp(request))
+                .withForwardedProto(getForwardedProto(request))
                 .withUserAgent(userAgent)
                 .withConfiguration(configuration);
     }
@@ -273,6 +276,10 @@ public class RequestUtil {
         return forwardedFor;
     }
 
+    public String getForwardedProto(HttpServletRequest request) {
+        return request.getHeader(HEADER_X_FORWARDED_PROTO);
+    }
+
     public UserAgentInfo parseUserAgent(String userAgent) {
         if (TextUtils.isEmpty(userAgent) || userAgent.length() > USER_AGENT_MAXLEN) {
             throw ApiFacadeException.invalidUserAgent();
